<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Penampil Gambar Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versi:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>gambar</translation>
    </message>
    <message>
        <source>images</source>
        <translation>gambar</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>album</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Atur sinkroninasi</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Menyinkronisasi:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baru</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Tidak ada nama</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Diimpor baru-baru ini</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit saya</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Apakah Anda yakin ingin menghapus album ini?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit saya</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Linimasa</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Anda dapat menambahkan sinkronisasi direktori atau seret dan lepas gambar pada linimasa</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Tidak ada nama</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pertunjukan slide</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Penampil Gambar Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Gambar</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Apakah ada yakin untuk menambah gambar ke album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sinkronisasi dan Buat</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sinkronisasi</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Apakah Anda yakin untuk menambahkan daftar sinkronisasi dan membuat album bernama setelah folder ini?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Ekspo berhasil</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Gagal mengekspor</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Apakah Anda yakin ingin melempar gambar ke TONG SAMPAH?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>File ini berisi beberapa halaman, silakan gunakan Evince untuk melihat semua halaman.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pertunjukan slide</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Anda dapat menambahkan direktori sinkronisasi atau seret dan lepas gambar pada linimasa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambahkan ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambahkan ke album baru</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Buka Direktori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Anda tidak punya hak akses untuk melihat gambar</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tanggal dimodifikasi</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensi</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Ukuran gambar</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Ruang warna</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode eksposur</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program eksposur</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Waktu eksposur</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Jarak fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertur maksimal</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode pengukuran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Keseimbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model lensa</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Tidak ada penskalaan</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Sesuaikan halaman dengan gambar</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Sesuaikan gambar dengan halaman</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skala untuk:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Sentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inci</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posisi Gambar</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Penskalaan</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Tirai</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Switcher</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ring</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Pilih Direktori</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Direktori ini dinon-aktifkan untuk sinkronisasi</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Tambah folder</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Manajemen sinkronisasi direktori</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Daftar direktori kosong</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Batalkan sinkronisasi</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Perangkat telah dilepaskan</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktori ini sudah tidak tersedia</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Menghitung...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Melihat Gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End show</source>
        <translation>Akhiri tampilan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Layar sebelumnya</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Layar sleanjutnya</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baru</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Silakan masukkan pintasan baru</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Lihat gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Kembalikan Bawaan</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End show</source>
        <translation>Akhiri tampilan</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baru</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Hentikan/Mainkan</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durasi</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Tukar durasi</translation>
    </message>
    <message>
        <source>second</source>
        <translation>detik</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Manajemen gambar</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit saya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Tidak ada berkas gambar ditemukan</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Gambar</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 gambar</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 gambar</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Atur sinkronisasi</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Menyingkronisasi:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambahkan ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambahkan ke album baru</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Salin ke papan klip</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>info gambar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efek</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durasi</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>hh BBBB tttt</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit saya</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Diimpor baru-baru ini</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Album baru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Linimasa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambahkan ke albu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambahkan ke album baru</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar layar penuh</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Tampilkan jendela navigasi</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sembunyikan jendela navigasi</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>